# flashinfer_bench.data.Trace

```{eval-rst}
.. currentmodule:: flashinfer_bench.data

.. autopydantic_model:: Trace

.. autopydantic_model:: Correctness

.. autopydantic_model:: Performance

.. autopydantic_model:: Environment

.. autoclass:: EvaluationStatus
    :members:

.. autopydantic_model:: Evaluation
```
